Welcome

Kingfisher is a fast and flexible program for procurement of sequence files (and
their annotations) from public data sources, including the European Nucleotide
Archive (ENA), NCBI SRA, Amazon AWS and Google Cloud. It's input is one or more
"Run" accessions e.g. DRR001970, or a BioProject accessions e.g. PRJNA621514 or
SRP260223.

For more documentation, see https://wwood.github.io/kingfisher-download/

<img src="images/kingfisher_logo.png" alt="Kingfisher logo" width="600"/>